<?php
/**
 * The Giapeto script to delete bookmarks.
 *
 * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
 *
 * See the enclosed file COPYING for license information (GPL). If you did not
 * receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * $Horde: giapeto/bookmarks/delete.php,v 1.14 2005/07/24 21:21:37 chuck Exp $
 *
 * @author Marko Djukic <marko@oblo.com>
 * @package Giapeto
 */

@define('GIAPETO_BASE', dirname(__FILE__) . '/..');
require_once GIAPETO_BASE . '/lib/base.php';
require_once 'Horde/Form.php';
require_once 'Horde/Form/Renderer.php';
require_once 'Horde/Variables.php';

/* Only registered users should be using this. */
if (!Auth::getAuth()) {
    Horde::authenticationFailureRedirect();
}

/* Get some variables. */
$vars = &Variables::getDefaultVariables();
$bookmark_id = $vars->get('bookmark_id');
$form_submit = $vars->get('submitbutton');

$vars = &new Variables($bookmarks->getBookmark($bookmark_id, true));

$form = &Horde_Form::singleton('', $vars, _("Delete this bookmark?"));

/* Set up the forms. */
$form->setButtons(array(_("Delete"), _("Do not delete")));
$form->addVariable(_("Bookmark"), 'path', 'text', false, true);
$form->addHidden('', 'bookmark_id', 'int', false);

if ($form_submit == _("Delete")) {
    $form->validate($vars);

    if ($form->isValid()) {
        $form->getInfo($vars, $info);
        $delete = $bookmarks->deleteBookmark($info['bookmark_id']);
        if (is_a($delete, 'PEAR_Error')) {
            Horde::logMessage($delete, __FILE__, __LINE__, PEAR_LOG_ERR);
            $notification->push(sprintf(_("Error deleting bookmark. %s."), $delete->getMessage()), 'horde.error');
        } else {
            $notification->push(_("Bookmark deleted."), 'horde.success');
            $url = Horde::applicationUrl('bookmarks/index.php', true);
            header('Location: ' . $url);
            exit;
        }
    }
} elseif (!empty($form_submit)) {
    $notification->push(_("Bookmark has not been deleted."), 'horde.message');
    $url = Horde::applicationUrl('bookmarks/index.php', true);
    header('Location: ' . $url);
    exit;
}

/* Render the form. */
$renderer = &new Horde_Form_Renderer();
$main = Util::bufferOutput(array($form, 'renderActive'), $renderer, $vars, 'delete.php', 'post');

$template = &new Horde_Template();
$template->set('notify', Util::bufferOutput(array($notification, 'notify')));
$template->set('main', $main);

require GIAPETO_TEMPLATES . '/common-header.inc';
echo $template->fetch(GIAPETO_TEMPLATES . '/bookmarks/main.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
