<?php
/**
 * The Giapeto script to delete a page.
 *
 * $Horde: giapeto/delete.php,v 1.29 2005/07/24 21:21:37 chuck Exp $
 *
 * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
 *
 * See the enclosed file COPYING for license information (GPL). If you did not
 * receive this file, see http://www.fsf.org/copyleft/gpl.html.
 */

@define('GIAPETO_BASE', dirname(__FILE__));
require_once GIAPETO_BASE . '/lib/base.php';
require_once 'Horde/Variables.php';
require_once 'Horde/Form.php';
require_once 'Horde/Form/Renderer.php';

$giapeto = &Giapeto::singleton();

$vars = &Variables::getDefaultVariables();
$page_id = $vars->get('page_id');
$form_submit = $vars->get('submitbutton');

$formdelete = &Horde_Form::singleton('', $vars, _("Delete a Page"));

/* Set up the form. */
$formdelete->setButtons(array(_("Delete"), _("Do not delete")));
$formdelete->addHidden('', 'page_id', 'int', true);
$formdelete->addVariable(_("Page name"), 'page_name', 'text', false, true);
$formdelete->addVariable(_("Subpages affected"), 'subpages', 'html', false, true);

if ($form_submit == _("Delete")) {
    $formdelete->validate($vars);

    if ($formdelete->isValid()) {
        $formdelete->getInfo($vars, $info);
        $page = $giapeto->getPage($info['page_id']);
        $parent = $giapeto->getParentName($page);

        /* Delete the page. */
        $delete = $giapeto->removePage($page);
        if (is_a($delete, 'PEAR_Error')) {
            Horde::logMessage($delete, __FILE__, __LINE__, PEAR_LOG_ERR);
            $notification->push(sprintf(_("Page delete failed. %s"), $delete->getMessage()), 'horde.error');
            $main = Util::bufferOutput(array($formdelete, 'renderActive'), $renderer, $vars, 'delete.php', 'post');
        } else {
            $notification->push(_("Page deleted."), 'horde.success');
            if ($parent == DATATREE_ROOT) {
                $url = Horde::applicationUrl('pages.php');
            } else {
                $url = $giapeto->getCategoryUrl($parent, true);
            }
            header('Location: ' . $url);
            exit;
        }
    }
} elseif (!empty($form_submit)) {
    $notification->push(_("Page not deleted."), 'horde.message');
    $url = $giapeto->getIdUrl($vars->get('page_id'));
    header('Location: ' . $url);
    exit;
} else {
    $vars->set('page_name', $giapeto->getIdUrl($page_id, true));

    /* Get subpages under the current one being deleted */
    $subtree = $giapeto->getSiteTree('cat_ids', $page_id);
    array_shift($subtree);
    $subpages = '';
    foreach ($subtree as $subpage) {
        $subpages .= $subpage . '<br />';
    }
    if (empty($subpages)) {
        $subpages = _("No subpages");
    }
    $vars->set('subpages', $subpages);
}

/* Render the form. */
$renderer = &new Horde_Form_Renderer();
$main = Util::bufferOutput(array($formdelete, 'renderActive'), $renderer, $vars, 'delete.php', 'post');

$template = &new Horde_Template();
$template->set('menu', Giapeto::getMenu('string'));
$template->set('notify', Util::bufferOutput(array($notification, 'notify'), array('listeners' => 'status')));
$template->set('main', $main);

require GIAPETO_TEMPLATES . '/common-header.inc';
echo $template->fetch(GIAPETO_TEMPLATES . '/main/main.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
