<?php
/**
 * The Giapeto script to modify the layout of a page.
 *
 * $Horde: giapeto/layout.php,v 1.33 2005/07/24 21:21:37 chuck Exp $
 *
 * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
 *
 * See the enclosed file COPYING for license information (GPL). If you did not
 * receive this file, see http://www.fsf.org/copyleft/gpl.html.
 */

@define('GIAPETO_BASE', dirname(__FILE__));
require_once GIAPETO_BASE . '/lib/base.php';
require_once 'Horde/Form.php';
require_once 'Horde/Variables.php';

$giapeto = &Giapeto::singleton();

/* Set up the form variables. */
$vars = &Variables::getDefaultVariables();
$page_id = $vars->get('page_id');
$page_layout = $vars->get('page_layout');
$block = $vars->get('block');
$action = $vars->get('action');

$form = &Horde_Form::singleton('', $vars, _("Modify Page Layout"));

/* Set up the form. */
$form->setButtons(_("Store"));
$form->addHidden('', 'page_id', 'int', true);
$form->addHidden('', 'page_layout', 'text', true);
$form->addVariable(_("Page Layout"), 'block', 'html', false, true);

/* If no current page layout get the stored one. */
if (empty($page_layout)) {
    $page = $giapeto->getPage($page_id);
    $page_layout = $page->getPageLayoutString();
    /* If no layout actually stored then set the default one block. */
    if (empty($page_layout)) {
        $page_layout = 'x';
    }
}

switch ($action) {
case 'insert':
    if ($block == 'top') {
        if (substr($page_layout, 0, 3) == '[x/') {
            $new_layout = substr_replace($page_layout, '[x/', 0, 1);
        } else {
            $new_layout = '[x/' . $page_layout . ']';
        }
    } elseif ($block == 'bottom') {
        if (substr($page_layout, -3) == '/x]') {
            $new_layout = substr_replace($page_layout, '/x]', -1, 1);
        } else {
        $new_layout = '[' . $page_layout . '/x]';
        }
    }
    break;

case 'splithoriz':
case 'splitvert':
case 'delete':
    $tbl_parts = explode('x', $page_layout);
    $new_layout = array_shift($tbl_parts);
    $count = 0;
    foreach ($tbl_parts as $tbl_part) {
        if (isset($block) && $block == $count) {
            if ($action == 'splitvert') {
                $new_layout .= '[x/x]' . $tbl_part;
            } elseif ($action == 'splithoriz') {
                $new_layout .= '[x|x]' . $tbl_part;
            } elseif ($action == 'delete') {
                $new_layout .= $tbl_part;
            }
        } else {
            $new_layout .= 'x' . $tbl_part;
        }
        $count++;
    }
    break;

default:
    $new_layout = $page_layout;
}

$page_layout = $new_layout;
if ($page_layout != 'x') {
    $page_layout = Giapeto::optimizePageLayout($page_layout);
}

$url = Horde::applicationUrl('layout.php');
$url = Util::addParameter($url, array('page_id' => $page_id, 'page_layout' => $page_layout));
$url_instop = Util::addParameter($url, 'action', 'insert');
$url_instop = Util::addParameter($url_instop, 'block', 'top');
$url_insbottom = Util::addParameter($url, 'action', 'insert');
$url_insbottom = Util::addParameter($url_insbottom, 'block', 'bottom');

$blocks = array();
$countMax = substr_count($page_layout, 'x');
for ($count = 0; $count < $countMax; $count++) {
    $url_b = Util::addParameter($url, 'block', $count);
    $url_vert = Util::addParameter($url_b, 'action', 'splitvert');
    $url_horiz = Util::addParameter($url_b, 'action', 'splithoriz');
    $url_del = Util::addParameter($url_b, 'action', 'delete');

    $blocks[$count] = '<table width="100%" border="1" cellpadding="0" cellspacing="0"><tr><td>' . ($count + 1) . '<br />';
    $blocks[$count] .= Horde::link($url_vert, _("Split vertical")) . Horde::img('block_splitvert.png', _("Split vertical")) . '</a>';
    $blocks[$count] .= Horde::link($url_horiz, _("Split horizontal")) . Horde::img('block_splithoriz.png', _("Split horizontal")) . '</a>';
    if ($page_layout != 'x') $blocks[$count] .= Horde::link($url_del, _("Delete")) . Horde::img('block_delete.png', _("Delete")) . '</a>';
    $blocks[$count] .= '<br /></td></tr></table>';
}

$page_layout_html = Giapeto::parsePageLayout($page_layout);

$blocks_html = Horde::link($url_instop, _("Insert top row")) . Horde::img('block_instop.png', _("Insert top row")) . '</a>';
$blocks_html .= vsprintf($page_layout_html, $blocks);
$blocks_html .= Horde::link($url_insbottom, _("Insert bottom row")) . Horde::img('block_insbottom.png', _("Insert bottom row")) . '</a>';

$vars->set('block', $blocks_html);
$vars->set('page_layout', $page_layout);

/* Process the form. */
if ($form->validate($vars)) {
    $form->getInfo($vars, $info);
    $page = &$giapeto->getPage($page_id);
    $page->setPageLayout($info['page_layout']);
    $result = $page->save();
    if (is_a($result, 'PEAR_Error')) {
        Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
        $notification->push(sprintf(_("Modifying page layout failed. %s"), $result->getMessage()), 'horde.error');
    } else {
        $notification->push(_("Page layout modified."), 'horde.success');
        $url = $giapeto->getIdUrl($giapeto->getPageId($page), 1);
        header('Location: ' . $url);
        exit;
    }
}

/* Render the form. */
require_once 'Horde/Form/Renderer.php';
$renderer = &new Horde_Form_Renderer();
$main = Util::bufferOutput(array($form, 'renderActive'), $renderer, $vars, 'layout.php', 'post');

$template = &new Horde_Template();
$template->set('main', $main);
$template->set('menu', Giapeto::getMenu('string'));
$template->set('notify', Util::bufferOutput(array($notification, 'notify'), array('listeners' => 'status')));

require GIAPETO_TEMPLATES . '/common-header.inc';
echo $template->fetch(GIAPETO_TEMPLATES . '/main/main.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
