<?php
/**
 * The Giapeto_Bookmarks:: class provides
 *
 * $Horde: giapeto/lib/Bookmarks.php,v 1.27 2005/08/24 05:32:50 selsky Exp $
 *
 * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
 *
 * See the enclosed file COPYING for license information (GPL). If you did not
 * receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * @author  Marko Djukic <marko@oblo.com>
 * @package Giapeto
 */
class Giapeto_Bookmarks {

    /**
     * A hash containing any parameters for the current driver.
     *
     * @var array
     */
    var $_params = array();

    /**
     * Constructor
     *
     * @param array $params  Any parameters needed for this driver.
     */
    function Giapeto_Bookmarks($params = '')
    {
        $this->_params = $params;
    }

    function getButton($page_id)
    {
        $button = array();

        Horde::addScriptFile('open_popup_win.js');

        /* Set text and link, depending on whether page not in bookmarks. */
        if ($this->isBookmarked($page_id)) {
            $text = _("View bookmarks");
            $link = Horde::applicationUrl('bookmarks/index.php');
        } else {
            $text = _("Add to bookmarks");
            $link = Horde::applicationUrl('bookmarks/edit.php');
            $link = Util::addParameter($link, 'page_id', $page_id);
        }

        $button['link'] = Horde::link('#', $text, '', '', 'open_popup_win(\'' . $link . '\', \'300\', \'400\', \'bookmarks\');return false;');
        $button['image'] = Horde::img('bookmarks.png', $text, 'align="middle"', $GLOBALS['registry']->getImageDir());
        $button['text'] = $text;

        return $button;
    }

    function getBookmarks($formatted = false)
    {
        /* Get bookmarks from backend. */
        $bookmarks = $this->_getBookmarks();

        /* If no formatting required return raw list; also bail if
         * there are no bookmarks. */
        if (!$formatted || !count($bookmarks)) {
            return $bookmarks;
        }

        /* Set up some vars. */
        $url = Horde::applicationUrl('bookmarks/index.php');
        $del_url = Horde::applicationUrl('bookmarks/delete.php');
        $edit_url = Horde::applicationUrl('bookmarks/edit.php');
        $del_img = Horde::img('delete.png', _("Delete"), '', $GLOBALS['registry']->getImageDir('horde'));
        $edit_img = Horde::img('edit.png', _("Edit"), '', $GLOBALS['registry']->getImageDir('horde'));
        $alert_img = Horde::img('alarm.png', _("Alert"), '', $GLOBALS['registry']->getImageDir());
        $subpages_img = Horde::img('tree.png', _("Subpages"), '', $GLOBALS['registry']->getImageDir());

        /* Build the list. */
        $bookmark_list = array();
        $i = 0;
        foreach ($bookmarks as $bookmark) {
            /* Delete link. */
            $link = Util::addParameter($del_url, 'bookmark_id', $bookmark['bookmark_id']);
            $bookmark_list[$i]['delete'] = Horde::link($link, _("Delete")) . $del_img . '</a>';

            /* Edit link. */
            $link = Util::addParameter($edit_url, 'bookmark_id', $bookmark['bookmark_id']);
            $bookmark_list[$i]['edit'] = Horde::link($link, _("Edit")) . $edit_img . '</a>';

            /* Bookmark and link. */
            $page = $GLOBALS['giapeto']->getIdUrl($bookmark['page_id'], DATATREE_ROOT);
            if ($page == '/') {
                $page = _("Home");
            }
            $bookmark_list[$i]['path'] = $page;
            $link = Util::addParameter($url, 'bookmark_id', $bookmark['bookmark_id']);
            $bookmark_list[$i]['link'] = Horde::link($link, $page) . $page . '</a>';

            /* Bookmark settings. */
            $bookmark_list[$i]['settings'] = ($bookmark['bookmark_alert']) ? $alert_img : '';
            $bookmark_list[$i]['settings'] .= ($bookmark['bookmark_subpages']) ? $subpages_img : '';

            $i++;
        }

        require_once 'Horde/Array.php';
        Horde_Array::arraySort($bookmark_list, 'path');
        return $bookmark_list;
    }

    function getWatchedPages()
    {
        global $giapeto;

        /* Get all the bookmarks from backend. */
        $bookmarks = $this->_getAllBookmarks();

        $watched = array();
        foreach ($bookmarks as $b) {
            if (!isset($watched[$b['page_id']])) {
                $watched[$b['page_id']] = array();
            }
            $watched[$b['page_id']][$b['user_uid']] = $b['bookmark_alert'];
            if ($b['bookmark_subpages']) {
                $subpages = $giapeto->getSiteTree('', $b['page_id']);
                foreach ($subpages as $s_id => $s) {
                    $watched[$s_id][$b['user_uid']] = $b['bookmark_alert'];
                }
            }
        }

        return $watched;
    }

    /**
     * Attempts to return a concrete Giapeto_Bookmarks instance based on
     * $driver.
     *
     * @param string $driver  The type of concrete Giapeto_Bookmarks subclass
     *                        to return.
     * @param array $params   A hash containing any additional configuration or
     *                        connection parameters a subclass might need.
     *
     * @return Giapeto_Bookmarks  The newly created concrete Giapeto_Bookmarks
     *                            instance, or false on error.
     */
    function &factory($driver, $params = array())
    {
        $driver = basename($driver);

        include_once dirname(__FILE__) . '/Bookmarks/' . $driver . '.php';
        $class = 'Giapeto_Bookmarks_' . $driver;
        if (class_exists($class)) {
            return $ret = &new $class($params);
        } else {
            Horde::fatal(PEAR::raiseError(sprintf(_("No such backend \"%s\" found"), $driver)), __FILE__, __LINE__);
        }
    }

    /**
     * Attempts to return a reference to a concrete Giapeto_Bookmarks instance
     * based on $driver.
     *
     * It will only create a new instance if no Giapeto_Bookmarks instance
     * with the same parameters currently exists.
     *
     * This should be used if multiple storage sources are required.
     *
     * This method must be invoked as: $var = &Giapeto_Bookmarks::singleton()
     *
     * @param string $driver  The type of concrete Giapeto_Bookmarks subclass
     *                        to return.
     * @param array $params   A hash containing any additional configuration
     *                        or connection parameters a subclass might need.
     *
     * @return mixed  The created concrete Giapeto_Bookmarks instance, or false
     *                on error.
     */
    function &singleton($driver, $params = array())
    {
        static $instances;

        if (!isset($instances)) {
            $instances = array();
        }

        $signature = serialize(array($driver, $params));
        if (!isset($instances[$signature])) {
            $instances[$signature] = &Giapeto_Bookmarks::factory($driver, $params);
        }

        return $instances[$signature];
    }

}
