<?php
/**
 * The Giapeto_Stats:: class keeps track of Giapeto page statistics.
 *
 * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
 *
 * See the enclosed file COPYING for license information (GPL). If you did not
 * receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * $Horde: giapeto/lib/Stats.php,v 1.15 2005/08/24 05:32:50 selsky Exp $
 *
 * @author  Marko Djukic <marko@oblo.com>
 * @package Giapeto
 */
class Giapeto_Stats {

    /**
     * A hash containing any parameters for the current driver.
     *
     * @var array
     */
    var $_params = array();

    /**
     * Constructor
     *
     * @param array $params  Any parameters needed for this driver.
     */
    function Giapeto_Stats($params = '')
    {
        $this->_params = $params;
    }

    /**
     * Log a page view. This first sets up the array of ietms to be logged
     * then calls the backend specific _log() function to physically log the
     * info.
     *
     * @param int $page_id  The page_id to log data for.
     */
    function log($page_id)
    {
        $log = array();
        $log['page_id'] = $page_id;
        $log['url'] = $GLOBALS['giapeto']->getIdUrl($page_id);
        $log['user'] = Auth::getAuth();
        $log['time'] = time();

        return $this->_log($log);
    }

    function getStats($page_id)
    {
        $stats = array();
        $stats['first_visit'] = strftime('%x %X', $this->getFirstVisit($page_id));
        $stats['last_visit'] = strftime('%x %X', $this->getLastVisit($page_id));
        $stats['total_views'] = $this->getTotalViews($page_id);
        $stats['total_users'] = $this->getTotalUsers($page_id);

        return $stats;
    }

    /**
     * Attempts to return a concrete Giapeto_Stats instance based on $driver.
     *
     * @param string $driver  The type of concrete Giapeto_Stats subclass to
     *                        return.
     * @param array $params   A hash containing any additional configuration or
     *                        connection parameters a subclass might need.
     *
     * @return Giapeto_Stats  The newly created concrete Giapeto_Stats
     *                        instance, or false on error.
     */
    function &factory($driver, $params = array())
    {
        $driver = basename($driver);
        include_once dirname(__FILE__) . '/Stats/' . $driver . '.php';
        $class = 'Giapeto_Stats_' . $driver;
        if (class_exists($class)) {
            return $ret = &new $class($params);
        } else {
            Horde::fatal(PEAR::raiseError(sprintf(_("No such backend \"%s\" found"), $driver)), __FILE__, __LINE__);
        }
    }

    /**
     * Attempts to return a reference to a concrete Giapeto_Stats instance
     * based on $driver.
     *
     * It will only create a new instance if no Giapeto_Stats instance with the
     * same parameters currently exists.
     *
     * This should be used if multiple storage sources are required.
     *
     * This method must be invoked as: $var = &Giapeto_Stats::singleton()
     *
     * @param string $driver  The type of concrete Giapeto_Stats subclass to
     *                        return.
     * @param array $params   A hash containing any additional configuration
     *                        or connection parameters a subclass might need.
     *
     * @return mixed  The created concrete Giapeto_Stats instance, or false
     *                on error.
     */
    function &singleton($driver, $params = array())
    {
        static $instances;

        if (!isset($instances)) {
            $instances = array();
        }

        $signature = serialize(array($driver, $params));
        if (!isset($instances[$signature])) {
            $instances[$signature] = &Giapeto_Stats::factory($driver, $params);
        }

        return $instances[$signature];
    }

}
