<?php
/**
 * The Giapeto script to move a page.
 *
 * $Horde: giapeto/move.php,v 1.24 2005/07/24 21:21:37 chuck Exp $
 *
 * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
 *
 * See the enclosed file COPYING for license information (GPL). If you did not
 * receive this file, see http://www.fsf.org/copyleft/gpl.html.
 */

@define('GIAPETO_BASE', dirname(__FILE__));
require_once GIAPETO_BASE . '/lib/base.php';
require_once 'Horde/Variables.php';

/* Form libraries */
require_once 'Horde/Form.php';
require_once 'Horde/Form/Renderer.php';

$giapeto = &Giapeto::singleton();

/* Set up the form variables. */
$vars = &Variables::getDefaultVariables();
$page_id = $vars->get('page_id');
$formname = $vars->get('formname');

$formmove = &Horde_Form::singleton('', $vars, _("Move a Page"));

/* Set up the form. */
$formmove->setButtons(_("Move"), true);
$formmove->addHidden('', 'page_id', 'int', true);
$formmove->addVariable(_("Move this page"), 'page_name', 'text', false, true);
$formmove->addVariable(_("Subpages affected"), 'subpages', 'html', false, true);
$sitetree = $giapeto->getSiteTree('cat_ids', DATATREE_ROOT, true, $giapeto->getPagePath($page_id));
$formmove->addVariable(_("To subpage of"), 'new_parent_id', 'enum', true, false, null, array($sitetree));

/* Set the values of form variables. */
$vars->set('page_name', $giapeto->getIdUrl($page_id, true));
$subtree = $giapeto->getSiteTree('cat_ids', $page_id);
array_shift($subtree);
$subpages = '';
foreach ($subtree as $subpage) {
    $subpages .= $subpage . '<br />';
}
if (empty($subpages)) {
    $subpages = _("No subpages");
}
$vars->set('subpages', $subpages);

/* Process the form. */
if ($formname) {
    $formmove->validate($vars);

    if ($formmove->isValid()) {
        $formmove->getInfo($vars, $info);
        $new_page_path = $giapeto->movePage($info['page_id'], $info['new_parent_id']);
        if (is_a($new_page_path, 'PEAR_Error')) {
            Horde::logMessage($new_page_path, __FILE__, __LINE__, PEAR_LOG_ERR);
            $notification->push(sprintf(_("Moving page failed. %s"), $new_page_path->getMessage()), 'horde.error');
        } else {
            $notification->push(_("Page moved."), 'horde.success');
            $url = $giapeto->getCategoryUrl($new_page_path, true);
            header('Location: ' . $url);
            exit;
        }
    }
}

/* Render the form. */
$renderer = &new Horde_Form_Renderer();
$main = Util::bufferOutput(array($formmove, 'renderActive'), $renderer, $vars, 'move.php', 'post');

$template = &new Horde_Template();
$template->set('menu', Giapeto::getMenu('string'));
$template->set('notify', Util::bufferOutput(array($notification, 'notify'), array('listeners' => 'status')));
$template->set('main', $main);

require GIAPETO_TEMPLATES . '/common-header.inc';
echo $template->fetch(GIAPETO_TEMPLATES . '/main/main.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
