<?php
/**
 * The Giapeto script to add permissions to a page.
 *
 * Copyright 2004-2005 Marko Djukic <marko@oblo.com>
 *
 * See the enclosed file COPYING for license information (GPL). If you did not
 * receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * $Horde: giapeto/perms/add.php,v 1.11 2005/08/24 05:32:51 selsky Exp $
 */

@define('GIAPETO_BASE', dirname(__FILE__) . '/..');
require_once GIAPETO_BASE . '/lib/base.php';

/* Set up the giapeto class */
$giapeto = &Giapeto::singleton();

$page_id = Util::getFormData('page_id');

$page = &$giapeto->getPage($page_id);
if (is_a($page, 'PEAR_Error')) {
    Horde::fatal($page, __FILE__, __LINE__);
}

/* Check if user authorised for this. */
if (!$giapeto_perms->checkPermissions($page_id, 'page', PERMS_EDIT)) {
    $notification->push(_("You are not authorized."), 'horde.error');
    $url = $giapeto->getIdUrl($page_id, 1);
    header('Location: ' . $url);
    exit;
}

$perm_name = 'giapeto:pages:' . $page_id;
$permission = &$perms->getPermission($perm_name);
if (!is_a($permission, 'PEAR_Error')) {
    $notification->push(sprintf(_("Permissions already exist for \"%s\"."), $page->getShortName()), 'horde.warning');
    $url = Horde::applicationUrl('perms/index.php', true);
    $url = Util::addParameter($url, 'page_id', $page_id);
    header('Location: ' . $url);
    exit;
}

/* Get the base permission. */
$permission = &$perms->getPermission('giapeto:pages');
if (is_a($permission, 'PEAR_Error')) {
    /* Create the base permission if missing. */
    $permission = &$perms->newPermission('giapeto:pages');
    $result = $perms->addPermission($permission);
}

/* Set up the permissions add form. */
require_once 'Horde/Perms/UI.php';
$perms_ui = &new Perms_UI($perms);
$perms_ui->setupAddForm($permission, $page_id);
$perms_ui->_form->addHidden('', 'page_id', 'text', false);

/* Validate the form. */
if ($perms_ui->validateAddForm($info)) {
    $name = 'giapeto:pages:' . DataTree::encodeName($info['child']);
    $child = &$perms->newPermission($name);
    $result = $perms->addPermission($child);

    if (is_a($result, 'PEAR_Error')) {
        $notification->push(sprintf(_("Permissions for \"%s\" not created. %s"), $page->getShortName(), $result->getMessage()), 'horde.error');
    } else {
        $notification->push(sprintf(_("Added permissions for \"%s\"."), $page->getShortName()), 'horde.success');
        $url = Horde::applicationUrl('perms/edit.php', true);
        $url = Util::addParameter($url, 'page_id', $info['page_id']);
        header('Location: ' . $url);
        exit;
    }

    $notification->push(sprintf(_("Updated \"%s\"."), $permission->getShortName()), 'horde.success');
    $url = Horde::applicationUrl('perms/index.php', true);
    $url = Util::addParameter($url, 'page_id', $permission->getShortName());
    header('Location: ' . $url);
    exit;
}

/* Set up template tags. */
$template = &new Horde_Template();
$template->set('menu', Giapeto::getMenu('string'));
$template->set('tree', $giapeto->renderPermsTree($page_id, $page_id));
$template->set('form', Util::bufferOutput(array($perms_ui, 'renderForm'), 'add.php'));

/* Set notification tag. */
$template->set('notify', Util::bufferOutput(array($notification, 'notify')));

require GIAPETO_TEMPLATES . '/common-header.inc';
echo $template->fetch(GIAPETO_TEMPLATES . '/perms/edit.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
