#!/usr/local/bin/php
<?php
/**
 * $Horde: giapeto/scripts/upgrades/2004-04-07_migrate_categories.php,v 1.2 2005/05/25 03:11:37 selsky Exp $
 *
 * Script to migrate the old way of storing page info in horde_categories data
 * field to the new horde_category_attributes table. You MUST create that table
 * before running this script.
 * In addition the script will:
 *  - Drop the 'type' field and just differentiate blocks according to whether
 *    they have a field 'text', 'app', 'image' or 'file'.
 *  - Change images stored in the 'file' type of block into an 'image' type for
 *    use in the Horde_Form image field type.
 *  - Strip out 'color' param into its own record.
 *  - Try not to store empty values, such as no colour set or no page template.
 */

/**
 * Set this to true if you want DB inserts done.
 */
$live = false;

// No need for auth.
@define('AUTH_HANDLER', true);

// Find the base file paths.
@define('HORDE_BASE', dirname(__FILE__) . '/../../..');
@define('GIAPETO_BASE', dirname(__FILE__) . '/../..');

// Do CLI checks and environment setup first.
require_once HORDE_BASE . '/lib/core.php';
require_once 'Horde/CLI.php';

// Make sure no one runs this from the web.
if (!Horde_CLI::runningFromCLI()) {
    exit("Must be run from the command line\n");
}

// Load the CLI environment - make sure there's no time limit, init
// some variables, etc.
Horde_CLI::init();

require_once 'DB.php';
require_once HORDE_BASE . '/lib/base.php';
require_once 'Horde/Serialize.php';
require_once 'Horde/Array.php';

/* Open the database. */
$db = &DB::connect($conf['sql']);
if (is_a($db, 'PEAR_Error')) {
   var_dump($db); exit;
}


/* Get the available pages. */
$pages = $db->getAll('SELECT * FROM horde_categories WHERE group_uid LIKE \'giapeto.pages.%\'', DB_FETCHMODE_ASSOC);
$attr = array();
foreach ($pages as $row) {
    $data = Horde_Serialize::unserialize($row['category_data'], $row['category_serialized'], NLS::getCharset());
    if (isset($data['page_format'])) {
        $attr[] = array('id'    => $row['category_id'],
                        'name'  => 'p',
                        'key'   => 'layout',
                        'value' => $data['page_format']);
    }
    if (!empty($data['page_template'])) {
        $attr[] = array('id'    => $row['category_id'],
                        'name'  => 'p',
                        'key'   => 'template',
                        'value' => $data['page_template']);
    }
    if (isset($data['blocks'])) {
        $blocks = $data['blocks'];
        unset($data['blocks']);
        foreach ($blocks as $id => $val) {
            switch ($val['type']) {
            case 'text':
                /* Set text content. */
                $text = array('vfs_id' => $val['vfs_id'],
                              'vfs_path' => $val['vfs_path']);
                $text = Horde_Serialize::serialize($text, SERIALIZE_UTF7_BASIC, NLS::getCharSet());
                $attr[] = array('id'    => $row['category_id'],
                                'name'  => 'b_' . $id,
                                'key'   => 'text',
                                'value' => $text);

                /* Set any link. */
                if (!empty($val['link'])) {
                    $attr[] = array('id'    => $row['category_id'],
                                    'name'  => 'b_' . $id,
                                    'key'   => 'link',
                                    'value' => $val['link']);
                }

                /* Set any color. */
                if (!empty($val['params']['color'])) {
                    $attr[] = array('id'    => $row['category_id'],
                                    'name'  => 'b_' . $id,
                                    'key'   => 'color',
                                    'value' => $val['params']['color']);
                }
                unset($val['params']['color']);

                /* Set style. */
                $style = Horde_Serialize::serialize($val['params'], SERIALIZE_UTF7_BASIC, NLS::getCharSet());
                $attr[] = array('id'    => $row['category_id'],
                                'name'  => 'b_' . $id,
                                'key'   => 'style',
                                'value' => $style);
                break;

            case 'inhook':
                /* Set app. */
                $attr[] = array('id'    => $row['category_id'],
                                'name'  => 'b_' . $id,
                                'key'   => 'app',
                                'value' => $val['app']);

                /* Set params. */
                $params = Horde_Serialize::serialize($val['params'], SERIALIZE_UTF7_BASIC, NLS::getCharSet());
                $attr[] = array('id'    => $row['category_id'],
                                'name'  => 'b_' . $id,
                                'key'   => 'params',
                                'value' => $params);
                break;

            case 'file':
                /* Set file content. */
                $file = array('vfs_id' => $val['vfs_id'],
                              'vfs_path' => $val['vfs_path']);
                $file = Horde_Serialize::serialize($file, SERIALIZE_UTF7_BASIC, NLS::getCharSet());

                /* Set either file or image. */
                if (substr($val['params']['mime-type'], 0, 5) == 'image') {
                    $key = 'image';
                } else {
                    $key = 'file';
                }
                if (isset($val['params']['image_zoom'])) {
                    $attr[] = array('id'    => $row['category_id'],
                                    'name'  => 'b_' . $id,
                                    'key'   => 'image_zoom',
                                    'value' => $val['params']['image_zoom']);
                    unset($val['params']['image_zoom']);
                }
                $attr[] = array('id'    => $row['category_id'],
                                'name'  => 'b_' . $id,
                                'key'   => $key,
                                'value' => $file);

                /* Set params. */
                $params = Horde_Serialize::serialize($val['params'], SERIALIZE_UTF7_BASIC, NLS::getCharSet());
                $attr[] = array('id'    => $row['category_id'],
                                'name'  => 'b_' . $id,
                                'key'   => 'params',
                                'value' => $params);
                break;
            }
        }
    }
}

/* Do the inserts if live. */
if ($live) {
    foreach ($attr as $a) {
        $sql = sprintf('INSERT INTO horde_category_attributes (category_id, attribute_name, attribute_key, attribute_value) VALUES (%s, %s, %s, %s)',
                       (int)$a['id'],
                       $db->quote($a['name']),
                       $db->quote($a['key']),
                       $db->quote($a['value']));
        $result = $db->query($sql);
        if (is_a($result, 'PEAR_Error')) {
            var_dump($result);
            exit;
        }
    }
} else {
    var_dump($attr);
}
